@@ -17,12 +17,16 @@ from streamlink.stream.hls import HLSStream
 ))
 class GOLTelevision(Plugin):
     def _get_streams(self):
+        self.session.http.headers.update({
+            "Origin": "https://goltelevision.com",
+            "Referer": "https://goltelevision.com/",
+        })
         url = self.session.http.get(
             "https://play.goltelevision.com/api/stream/live",
             schema=validate.Schema(
                 validate.parse_json(),
                 {"manifest": validate.url()},
-                validate.get("manifest")
+                validate.get("manifest"),
             )
         )
         return HLSStream.parse_variant_playlist(self.session, url)
