@@ -1,9 +1,16 @@
+"""
+$description Live TV channels and video on-demand service from MRT, a North Macedonian public, state-owned broadcaster.
+$url play.mrt.com.mk
+$type live, vod
+$region North Macedonia
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
